@@ -197,7 +197,7 @@ class Extractor:
         date_dig = re.finditer(
             "(去年|今年|前年|明年|前一年)?\d{1,2}月\d{1,2}[号|日]|\d{4}年\d{1,2}月\d{1,2}[号|日]|\d{4}[-\./]\d{1,2}[-\./]\d{1,2}|"
             "\d{4}年\d{1,2}月|\d{4}年|\d{4}-\d{1,2}|\d{4}\.\d{1,2}|\d{4}/\d{1,2}|"
-            "\d{2}[:：]\d{2}([:：]\d{2})?|\d{1,2}[点｜时]\d{1,2}[分｜分钟](\d{1,2}[秒])?",
+            "\d{2}[:：]\d{2}([:：]\d{2})?|\d{1,2}[点|时]\d{1,2}[分|分钟](\d{1,2}[秒])?",
             text)
         if date_dig:
             for dd in date_dig:
@@ -339,16 +339,22 @@ class Extractor:
             final_res["document_no_full"] += org_name
             final_res["document_department_without_tail"] = utils.max_backward_match_end(org_name, self.keyword)
 
-        res = re.search('[〔\[\(［]?\s*([0-9]{4})\s*[〕\]\)］]?\s*[年]?\s*[第]?\s*([0-9]+)\s*号', query)
+        res = re.search('[〔\[\(［]?\s*([0-9]{4})\s*[〕\]\)］]?\s*[年]?\s*[第]?\s*([0-9]+)\s*(号|期|号文)', query)
         if res:
             final_res["document_no_full"] += res.group(0)
             year = res.group(1)
             number = res.group(2)
         else:
-            res = re.search('[第]?\s*([0-9]+)\s*号[文]?', query)
+            res = re.search('[第]?\s*([0-9]+)\s*(号|号文|期)?', query)
             if res:
                 final_res["document_no_full"] += res.group(0)
                 number = res.group(1)
+            else:
+                res = re.search('（([0-9]{6})）')
+                if res:
+                    final_res["document_no_full"] += res.group(0)
+                    number = res.group(1)
+
         res = re.search('[a-zA-Z]+/[a-zA-Z]+\s*[0-9]+(\.[0-9]+)?[—-][0-9]{4}', query)
         if res:
             another_number = res.group(0)
@@ -417,12 +423,11 @@ class Extractor:
 
 
 
-
+"""
 if __name__ == '__main__':
     et = Extractor()
     res = et.extract_reference_no("JR/T0247—2022/证监会公告〔2022〕30号")
     print(res)
-    exit(0)
     print(datetime.today())
     start = time.time()
     # text = "2021-03-0914:00开庭审理杨峰？"
@@ -477,4 +482,4 @@ if __name__ == '__main__':
         res = et.extract_time(text, cut_res)
         print(res)
     print((time.time() - start)/len(li))
-
+"""
