@@ -132,16 +132,14 @@ def max_backward_match(word_list, vocab, max_k=5):
 
 
 def max_backward_match_end(word_list, vocab, max_k=3):
-    res = [word_list]
     end = len(word_list)
     for i in range(max_k):
         start = end - max_k + i
         start = start if start >= 0 else 0
         temp = "".join(word_list[start:end])
         if temp in vocab:
-            res.append(word_list[:start])
-            break
-    return res
+            return word_list[:start]
+    return None
 
 
 def cut_text_index(word_list):
